<?xml version="1.0" encoding="utf-8"?>
<!-- item title="Report" -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="2.0"
                xmlns:exslt="http://exslt.org/common"
                xmlns:msxsl="urn:schemas-microsoft-com:xslt"
                exclude-result-prefixes="exslt msxsl">
    
    <xsl:output encoding='utf-8' doctype-public='-//W3C//DTD HTML 4.01 Transitional//EN' doctype-system='http://www.w3.org/TR/html4/loose.dtd' method='html'/>
    
    <msxsl:script language="JScript" implements-prefix="exslt">
        this['node-set'] =  function (x) {
        return x;
        }
    </msxsl:script>

    <xsl:param name="sortby" select="/report/@sort-by"/>
    <xsl:param name="duration" select="/report/@displayed-duration"/>
    <xsl:param name="anonym" select="/report/@anonym"/>
    <xsl:param name="sortorder" select="/report/@sort-order"/>
    <xsl:param name="groupby" select="/report/@group-by"/>
    <xsl:param name="sortordergroup">
        <xsl:choose>
            <xsl:when test="$groupby='time'">
                <xsl:choose>
                    <xsl:when test="$sortby!='time'">
                        <xsl:value-of select="'ascending'"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="/report/@sort-order"/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:when>
            <xsl:when test="$groupby='obj'">
                <xsl:choose>
                    <xsl:when test="$sortby!='obj'">
                        <xsl:value-of select="'ascending'"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="/report/@sort-order"/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="/report/@sort-order"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:param>
    <xsl:param name="print">
        <xsl:choose>
            <xsl:when test="/report/@print='1' or /report/@print='true'">
                <xsl:value-of select="'true'"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="'false'"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:param>
    <xsl:param name="port" select="/report/@voice-player-port"/>

    <xsl:template match="/report">
        <html>
            <head>
                <link rel="stylesheet" href="report.css" type="text/css"/>  
            </head>
            <body>
                <xsl:if test="count(record)=0">
                    <div class="no-records">
                        <xsl:value-of select="translation/no-records"/>
                    </div>
                </xsl:if>
                <xsl:if test="count(record)>0">
                    <xsl:if test="@href">
                        <xsl:if test="$print='false'">
                            <table class="record-save">
                                <tr>
                                    <xsl:variable name="href" select="concat(@href, '&amp;sortorder=', $sortorder, '&amp;sortby=', $sortby)"/>
                                    <td>
                                        <xsl:variable name="printxsl" select="concat($href, '&amp;format=xsl&amp;print=1')"/>
                                        <a href="{$printxsl}" target="_blank">
                                            <img class="icon" src="app-images/printer.jpg"/>
                                        </a>
                                    </td>
                                    <td>
                                        <xsl:variable name="savepdf" select="concat($href, '&amp;format=pdf')"/>
                                        <a href="{$savepdf}" name="recordsavepdf" title="PDF">
                                            <img class="icon" src="app-images/file_pdf.jpg"/>
                                        </a>
                                    </td>
                                    <td>
                                        <xsl:variable name="savexml" select="concat($href, '&amp;format=xml')"/>
                                        <a href="{$savexml}" name="recordsavexml" title="XML">
                                            <img class="icon" src="app-images/file_xml.jpg"/>
                                        </a>
                                    </td>
                                    <td>
                                        <xsl:variable name="savecsv" select="concat($href, '&amp;format=csv')"/>
                                        <a href="{$savecsv}" name="recordsavecsv" title="CSV">
                                            <img class="icon" src="app-images/file_csv.jpg"/>
                                        </a>
                                    </td>
                                </tr>
                            </table>
                        </xsl:if>
                        <!--<xsl:if test="@print">
                            <table class="record-save">
                                <tr>
                                    <td class="img">
                                        <a href="javascript:window.print()">
                                            <img class="icon" src="app-images/printer.jpg"/>
                                        </a>
                                    </td>
                                </tr>
                            </table>
                        </xsl:if>-->
                    </xsl:if>
                    <div>
                        <fieldset class="summary">
                            <legend>
                                <xsl:value-of select="translation/sum-io"/>
                            </legend>
                            <table class="summary">
                                <xsl:if test="count(record)>=/report/@limit">
                                    <tr class="summary-tr">
                                        <td class="summary-td-limit" colspan="2">
                                            <xsl:value-of select="translation/limit"/>
                                        </td>
                                    </tr>
                                </xsl:if>
                                <tr class="summary-tr">
                                    <td class="summary-td-desc">
                                        <xsl:value-of select="translation/sum-calls-io"/>
                                    </td>
                                    <td class="summary-td-value">
                                        <xsl:value-of select="summary/calls/incoming"/>
                                        <xsl:value-of select="' / '"/>
                                        <xsl:value-of select="summary/calls/outgoing"/>
                                    </td>
                                </tr>
                                <tr class="summary-tr">
                                    <td class="summary-td-desc">
                                        <xsl:value-of select="translation/sum-dur-io"/>
                                    </td>
                                    <td class="summary-td-value">
                                        <xsl:call-template name="sec2hour">
                                            <xsl:with-param name="seconds" select="summary/duration/incoming"/>
                                        </xsl:call-template>
                                        <xsl:value-of select="' / '"/>
                                        <xsl:call-template name="sec2hour">
                                            <xsl:with-param name="seconds" select="summary/duration/outgoing"/>
                                        </xsl:call-template>
                                    </td>
                                </tr>
                                <tr class="summary-tr">
                                    <td class="summary-td-desc">
                                        <xsl:value-of select="translation/sum-alert-dur-io"/>
                                    </td>
                                    <td class="summary-td-value">
                                        <xsl:call-template name="sec2hour">
                                            <xsl:with-param name="seconds" select="summary/duration/alert-incoming"/>
                                        </xsl:call-template>
                                        <xsl:value-of select="' / '"/>
                                        <xsl:call-template name="sec2hour">
                                            <xsl:with-param name="seconds" select="summary/duration/alert-outgoing"/>
                                        </xsl:call-template>
                                    </td>
                                </tr>
                            </table>
                            <xsl:if test="filter-info">
                                <table class="filter-info">
                                    <tr class="filter-info-tr">
                                        <td class="filter-info-td-desc">
                                            <xsl:value-of select="translation/filter-name"/>
                                        </td>
                                        <td class="filter-info-td-value">
                                            <xsl:value-of select="filter-info/name"/>
                                        </td>
                                    </tr>
                                    <tr class="filter-info-tr">
                                        <td class="filter-info-td-desc">
                                            <xsl:value-of select="translation/filter-names"/>
                                        </td>
                                        <td class="filter-info-td-value">
                                            <xsl:value-of select="filter-info/names"/>
                                        </td>
                                    </tr>
                                    <tr class="filter-info-tr">
                                        <td class="filter-info-td-desc">
                                            <xsl:value-of select="translation/pbx"/>
                                        </td>
                                        <td class="filter-info-td-value">
                                            <xsl:value-of select="filter-info/pbx"/>
                                        </td>
                                    </tr>
                                    <tr class="filter-info-tr">
                                        <td class="filter-info-td-desc">
                                            <xsl:value-of select="translation/object-long-name"/>
                                        </td>
                                        <td class="filter-info-td-value">
                                            <xsl:value-of select="filter-info/object"/>
                                        </td>
                                    </tr>
                                    <tr class="filter-info-tr">
                                        <td class="filter-info-td-desc">
                                            <xsl:value-of select="translation/from"/>
                                        </td>
                                        <td class="filter-info-td-value">
                                            <xsl:value-of select="filter-info/from"/>
                                        </td>
                                    </tr>
                                    <tr class="filter-info-tr">
                                        <td class="filter-info-td-desc">
                                            <xsl:value-of select="translation/to"/>
                                        </td>
                                        <td class="filter-info-td-value">
                                            <xsl:value-of select="filter-info/to"/>
                                        </td>
                                    </tr>
                                    <tr class="filter-info-tr">
                                        <td class="filter-info-td-desc">
                                            <xsl:value-of select="translation/group-by"/>
                                        </td>
                                        <td class="filter-info-td-value">
                                            <xsl:value-of select="filter-info/group-by"/>
                                        </td>
                                    </tr>
                                    <tr class="filter-info-tr">
                                        <td class="filter-info-td-desc">
                                            <xsl:value-of select="translation/displayed-duration"/>
                                        </td>
                                        <td class="filter-info-td-value">
                                            <xsl:value-of select="filter-info/displayed-duration"/>
                                        </td>
                                    </tr>
                                    <xsl:if test="filter-info/sort-by">
                                        <tr class="filter-info-tr">
                                            <td class="filter-info-td-desc">
                                                <xsl:value-of select="translation/sort-by"/>
                                            </td>
                                            <td class="filter-info-td-value">
                                                <xsl:value-of select="filter-info/sort-by"/>
                                            </td>
                                        </tr>
                                    </xsl:if>
                                    <xsl:if test="filter-info/sort-order">
                                        <tr class="filter-info-tr">
                                            <td class="filter-info-td-desc">
                                                <xsl:value-of select="translation/sort-order"/>
                                            </td>
                                            <td class="filter-info-td-value">
                                                <xsl:value-of select="filter-info/sort-order"/>
                                            </td>
                                        </tr>
                                    </xsl:if>
                                    <tr class="filter-info-tr">
                                        <td class="filter-info-td-desc">
                                            <xsl:value-of select="translation/hide-digits"/>
                                        </td>
                                        <td class="filter-info-td-value">
                                            <xsl:value-of select="filter-info/hide-digits"/>
                                        </td>
                                    </tr>
                                    <tr class="filter-info-tr">
                                        <td class="filter-info-td-desc">
                                            <xsl:value-of select="translation/anonym"/>
                                        </td>
                                        <td class="filter-info-td-value">
                                            <xsl:choose>
                                                <xsl:when test="$anonym">
                                                    <xsl:value-of select="translation/yes"/>
                                                </xsl:when>
                                                <xsl:otherwise>
                                                    <xsl:value-of select="translation/no"/>
                                                </xsl:otherwise>
                                            </xsl:choose>
                                        </td>
                                    </tr>
                                </table>
                            </xsl:if>
                        </fieldset>
                        <table class="record">
                            <tr class="record-tr-head">
                                <xsl:apply-templates select="translation/time"/>
                                <xsl:if test="$groupby!='obj' and not($anonym)">
                                    <xsl:apply-templates select="translation/obj"/>
                                </xsl:if>
                                <xsl:apply-templates select="translation/*[name(.)=$duration]"/>
                                <xsl:apply-templates select="translation/alert-duration"/>
                                <td class="record-td-head"/>
                                <td class="record-td-head">
                                    <xsl:value-of select="translation/left"/>
                                </td>
                                <xsl:apply-templates select="translation/dir"/>
                                <xsl:apply-templates select="translation/status"/>
                                <td class="record-td-head">
                                    <xsl:value-of select="translation/right"/>
                                </td>
                                <td class="record-td-head"/>
                            </tr>
                            <xsl:if test="not($sortby) or $sortby=''">
                                <xsl:apply-templates select="/report/record"/>
                            </xsl:if>
                            <xsl:if test="$sortby and $sortby!=''">
                                <xsl:variable name="records">
                                    <xsl:copy-of select="//translation"/>
                                    <xsl:choose>
                                        <xsl:when test="$sortby='time'">
                                            <xsl:for-each select="record">
                                                <xsl:sort select="@group-by-sort" order="{$sortordergroup}"/>
                                                <xsl:sort select="time" order="{$sortorder}"/>
                                                <xsl:sort select="obj" order="ascending"/>
                                                <xsl:copy-of select="."/>
                                            </xsl:for-each>
                                        </xsl:when>
                                        <xsl:when test="$sortby='obj'">
                                            <xsl:for-each select="record">
                                                <xsl:sort select="@group-by-sort" order="{$sortordergroup}"/>
                                                <xsl:sort select="obj" order="{$sortorder}"/>
                                                <xsl:sort select="time" order="ascending"/>
                                                <xsl:copy-of select="."/>
                                            </xsl:for-each>
                                        </xsl:when>
                                        <xsl:when test="$sortby='call-duration'">
                                            <xsl:for-each select="record">
                                                <xsl:sort select="@group-by-sort" order="{$sortordergroup}"/>
                                                <xsl:sort select="*[name(.)=$duration]/@seconds" order="{$sortorder}" data-type="number"/>
                                                <xsl:sort select="time" order="ascending"/>
                                                <xsl:copy-of select="."/>
                                            </xsl:for-each>
                                        </xsl:when>
                                        <xsl:when test="$sortby='alert-duration'">
                                            <xsl:for-each select="record">
                                                <xsl:sort select="@group-by-sort" order="{$sortordergroup}"/>
                                                <xsl:sort select="alert-duration/@seconds" order="{$sortorder}" data-type="number"/>
                                                <xsl:sort select="time" order="ascending"/>
                                                <xsl:copy-of select="."/>
                                            </xsl:for-each>
                                        </xsl:when>
                                        <xsl:when test="$sortby='dir'">
                                            <xsl:for-each select="record">
                                                <xsl:sort select="@group-by-sort" order="{$sortordergroup}"/>
                                                <xsl:sort select="dir" order="{$sortorder}"/>
                                                <xsl:sort select="time" order="ascending"/>
                                                <xsl:copy-of select="."/>
                                            </xsl:for-each>
                                        </xsl:when>
                                        <xsl:when test="$sortby='status'">
                                            <xsl:for-each select="record">
                                                <xsl:sort select="@group-by-sort" order="{$sortordergroup}"/>
                                                <xsl:sort select="status" order="{$sortorder}"/>
                                                <xsl:sort select="time" order="ascending"/>
                                                <xsl:copy-of select="."/>
                                            </xsl:for-each>
                                        </xsl:when>
                                    </xsl:choose>
                                </xsl:variable>
                                <xsl:apply-templates select="exslt:node-set($records)/record"/>
                            </xsl:if>
                        </table>
                    </div>
                </xsl:if>
            </body>
        </html>
    </xsl:template>

    <xsl:template match="translation/*">
        <td class="record-td-head">
            <xsl:if test="$print='true'">
                <xsl:call-template name="column-head">
                    <xsl:with-param name="name" select="name()"/>
                    <xsl:with-param name="text" select="text()"/>
                </xsl:call-template>
            </xsl:if>
            <xsl:if test="$print='false'">
                <xsl:variable name="tag">
                    <xsl:choose>
                        <xsl:when test="name()='flow'">
                            <xsl:value-of select="'status'"/>
                        </xsl:when>
                        <xsl:when test="contains(name(), 'duration') and name()!='alert-duration'">
                            <xsl:value-of select="'call-duration'"/>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:value-of select="name()"/>
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:variable>
                <a href="javascript:sortXML('{$tag}')" class="sortlink">
                    <xsl:call-template name="column-head">
                        <xsl:with-param name="name" select="name()"/>
                        <xsl:with-param name="text" select="text()"/>
                    </xsl:call-template>
                    <xsl:if test="$sortby=$tag or ($sortby='' and $tag='time')">
                        <xsl:value-of select="' '"/>
                        <xsl:if test="$sortorder='ascending'">
                            <img valign="center" src="classes/images/page-up.png"/>
                        </xsl:if>
                        <xsl:if test="$sortorder='descending'">
                            <img valign="center" src="classes/images/page-down.png"/>
                        </xsl:if>
                    </xsl:if>
                </a>
            </xsl:if>
        </td>
    </xsl:template>

    <xsl:template name="column-head">
        <xsl:param name="name"/>
        <xsl:param name="text"/>
        <xsl:choose>
            <xsl:when test="$name='dir'">
                <img class="call-icon" src="app-images/dir.jpg"/>
            </xsl:when>
            <xsl:when test="$name='status'">
                <img class="call-icon" src="app-images/state.jpg"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="$text"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    <xsl:template match="record">
        <!--
            As sorted records are given here, one can't access the parent level //report inside this template.
            So copy necessary nodes to the tree with <xsl:copy-of....
        -->
        <xsl:variable name="colspan">
            <xsl:choose>
                <xsl:when test="$groupby='obj' or $anonym">
                    <xsl:value-of select="5"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="6"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:if test="$groupby != ''">
            <xsl:if test="@group-by != preceding-sibling::record[1]/@group-by or position()=1">
                <tr class="record-tr-group-by">
                    <td colspan="{$colspan + 4}" class="record-td-group-by">
                        <xsl:choose>
                            <xsl:when test="$anonym and $groupby='obj'">
                                <xsl:value-of select="'*'"/>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:value-of select="@group-by"/>
                            </xsl:otherwise>
                        </xsl:choose>
                    </td>
                </tr>
            </xsl:if>
        </xsl:if>
        <xsl:if test="not(further-registration)">
            <xsl:variable name="fieldclass">
                <xsl:if test="position() mod 2 = 1">
                    <xsl:value-of select="'record-tr-field-odd'"/>
                </xsl:if>
                <xsl:if test="position() mod 2 = 0">
                    <xsl:value-of select="'record-tr-field-even'"/>
                </xsl:if>
            </xsl:variable>
            <tr class="{$fieldclass}">
                <td class="record-td-field">
                    <xsl:if test="not($groupby='time')">
                        <xsl:value-of select="substring-before(time, ' ')"/>
                        <xsl:value-of select="' '"/>
                    </xsl:if>
                    <xsl:value-of select="substring-after(time, ' ')"/>
                </td>
                <xsl:if test="$groupby!='obj' and not($anonym)">
                    <td class="record-td-field">
                        <xsl:value-of select="obj"/>
                    </td>
                </xsl:if>
                <td class="record-td-field duration">
                    <xsl:value-of select="*[name(.)=$duration]"/>
                    <xsl:choose>
                        <xsl:when test="vr-path">
                            <xsl:variable name="vrpath">
                                <xsl:value-of select="vr-path"/>
                            </xsl:variable>
                            <xsl:variable name="playerurl">
                                <xsl:value-of select="'http://127.0.0.1:'"/>
                                <xsl:value-of select="$port"/>
                                <xsl:value-of select="'/IPL'"/>
                            </xsl:variable>
                            <div class="voice-player">
                                <a href="ivoiceplayer:{$playerurl}TRAC{$vrpath}" class="voice-play voice-icon">
                                    <xsl:value-of select="' '"/>
                                </a>
                                <a href="ivoiceplayer:{$playerurl}PAUS" class="voice-pause voice-icon">
                                    <xsl:value-of select="' '"/>
                                </a>
                                <a href="ivoiceplayer:{$playerurl}STOP" class="voice-stop voice-icon">
                                    <xsl:value-of select="' '"/>
                                </a>
                            </div>
                        </xsl:when>
                        <xsl:otherwise>
                            <div class="voice-player"/>
                        </xsl:otherwise>
                    </xsl:choose>
                </td>
                <td class="record-td-field duration">
                    <xsl:value-of select="alert-duration"/>
                </td>
                <xsl:apply-templates select="flow/ev[1]">
                    <xsl:with-param name="class" select="'record-td-field'"/>
                    <xsl:with-param name="position" select="'1'"/>
                </xsl:apply-templates>
            </tr>
            <xsl:if test="flow/ev[2]">
                <xsl:for-each select="flow/ev">
                    <xsl:if test="(position() > 1)">
                        <tr class="record-tr-ev">
                            <td class="record-td-field-event" colspan="{$colspan - 2}"/>
                            <xsl:apply-templates select=".">
                                <xsl:with-param name="class" select="'record-td-field-event'"/>
                                <xsl:with-param name="position" select="position()"/>
                            </xsl:apply-templates>
                        </tr>
                    </xsl:if>
                </xsl:for-each>
            </xsl:if>
        </xsl:if>
        <xsl:if test="$groupby != ''">
            <xsl:if test="@group-by != following-sibling::record[1]/@group-by or position()=count(//record)">
                <xsl:variable name="curgroup">
                    <xsl:value-of select="@group-by"/>
                </xsl:variable>
                <tr class="record-tr-group-by">
                    <td colspan="{$colspan + 4}">
                        <table class="record-summary" align="right">
                            <tr class="record-tr-group-by-summary">
                                <td class="record-td-group-by-summary">
                                    <xsl:value-of select="//translation/incoming"/>
                                    <xsl:value-of select="' '"/>
                                    <xsl:value-of select="count(//record[@group-by=$curgroup and not(further-registration)]/dir[text()='i'])"/>
                                </td>
                                <td class="record-td-group-by-summary">
                                    <xsl:value-of select="//translation/outgoing"/>
                                    <xsl:value-of select="' '"/>
                                    <xsl:value-of select="count(//record[@group-by=$curgroup and not(further-registration)]/dir[text()='o'])"/>
                                </td>
                                <td class="record-td-group-by-summary">
                                    <xsl:value-of select="//translation/*[name(.)=$duration]"/>
                                    <xsl:value-of select="' '"/>
                                    <xsl:call-template name="sec2hour">
                                        <xsl:with-param name="seconds" select="sum(//record[@group-by=$curgroup and not(further-registration)]/*[name(.)=$duration]/@seconds)"/>
                                    </xsl:call-template>
                                </td>
                                <td class="record-td-group-by-summary">
                                    <xsl:value-of select="//translation/alert-duration"/>
                                    <xsl:value-of select="' '"/>
                                    <xsl:call-template name="sec2hour">
                                        <xsl:with-param name="seconds" select="sum(//record[@group-by=$curgroup and not(further-registration)]/alert-duration/@seconds)"/>
                                    </xsl:call-template>
                                </td>
                            </tr>
                        </table>
                    </td>
                </tr>
            </xsl:if>
        </xsl:if>
    </xsl:template>

    <xsl:template match="ev">
        <xsl:param name="class"/>
        <xsl:param name="position"/>
        <td class="{$class}">
            <xsl:call-template name="type-image">
                <xsl:with-param name="e164" select="@ep1_number"/>
                <xsl:with-param name="h323" select="@ep1_name"/>
                <xsl:with-param name="dn" select="@ep1_dn"/>
                <xsl:with-param name="type" select="@type"/>
                <xsl:with-param name="side" select="'left'"/>
            </xsl:call-template>
        </td>
        <td class="{$class}">
            <xsl:call-template name="format-ep">
                <xsl:with-param name="e164" select="@ep1_number"/>
                <xsl:with-param name="h323" select="@ep1_name"/>
                <xsl:with-param name="dn" select="@ep1_dn"/>
                <xsl:with-param name="position" select="$position"/>
            </xsl:call-template>
        </td>
        <td class="{$class}">
            <xsl:call-template name="direction-image">
                <xsl:with-param name="caller" select="@caller"/>
            </xsl:call-template>
        </td>
        <td class="{$class}">
            <xsl:if test="../../callback/@time and $position=1">
                <xsl:attribute name="title">
                    <xsl:value-of select="../../callback"/>
                    <xsl:value-of select="' (UTC): '"/>
                    <xsl:call-template name="format-ep">
                        <xsl:with-param name="e164" select="../../callback/@number"/>
                        <xsl:with-param name="h323" select="../../callback/@name"/>
                        <xsl:with-param name="dn" select="../../callback/@dn"/>
                        <xsl:with-param name="position" select="'1'"/>
                    </xsl:call-template>
                </xsl:attribute>
            </xsl:if>
            <xsl:call-template name="status-image">
                <xsl:with-param name="status" select="@status"/>
            </xsl:call-template>
        </td>
        <td class="{$class}">
            <xsl:call-template name="format-ep">
                <xsl:with-param name="e164" select="@ep2_number"/>
                <xsl:with-param name="h323" select="@ep2_name"/>
                <xsl:with-param name="dn" select="@ep2_dn"/>
                <xsl:with-param name="position" select="$position"/>
            </xsl:call-template>
        </td>
        <td class="{$class}">
            <xsl:call-template name="type-image">
                <xsl:with-param name="e164" select="@ep2_number"/>
                <xsl:with-param name="h323" select="@ep2_name"/>
                <xsl:with-param name="dn" select="@ep2_dn"/>
                <xsl:with-param name="type" select="@type"/>
                <xsl:with-param name="side" select="'right'"/>
            </xsl:call-template>
        </td>
    </xsl:template>
    
    <xsl:template name="sec2hour">
        <xsl:param name="seconds"/>
        <xsl:variable name="sec" select="number($seconds) mod 60"/>
        <xsl:variable name="min" select="(number($seconds) div 60) mod 60"/>
        <xsl:variable name="hour" select="(number($seconds) div 60) div 60"/>
        <xsl:value-of select="floor($hour)"/>
        <xsl:value-of select="':'"/>
        <xsl:if test="$min &lt; 10">
            <xsl:value-of select="'0'"/>
        </xsl:if>
        <xsl:value-of select="floor($min)"/>
        <xsl:value-of select="':'"/>
        <xsl:if test="$sec &lt; 10">
            <xsl:value-of select="'0'"/>
        </xsl:if>
        <xsl:value-of select="floor($sec)"/>
    </xsl:template>
    
    <xsl:template name="type-image">
        <xsl:param name="h323"/>
        <xsl:param name="e164"/>
        <xsl:param name="dn"/>
        <xsl:param name="type"/>
        <xsl:param name="side"/>
        <xsl:if test="$type and $type!='' and ($h323 or $e164 or $dn)">
            <xsl:choose>
                <xsl:when test="$type='ct' and $side='left'">
                    <img src="app-images/ct.jpg"/>
                </xsl:when>
                <xsl:when test="$type='ct' and $side='right'">
                    <img src="app-images/ct_rev.jpg"/>
                </xsl:when>
                <xsl:when test="$type='cct' and $side='left'">
                    <img src="app-images/cct.jpg"/>
                </xsl:when>
                <xsl:when test="$type='cct' and $side='right'">
                    <img src="app-images/cct_rev.jpg"/>
                </xsl:when>
                <xsl:when test="$type='cf' and $side='left'">
                    <img src="app-images/cf.jpg"/>
                </xsl:when>
                <xsl:when test="$type='cf' and $side='right'">
                    <img src="app-images/cf_rev.jpg"/>
                </xsl:when>
                <xsl:when test="$type='pu' and $side='left'">
                    <img src="app-images/pickup.jpg"/>
                </xsl:when>
                <xsl:when test="$type='pu' and $side='right'">
                    <img src="app-images/pickup_rev.jpg"/>
                </xsl:when>
            </xsl:choose>
        </xsl:if>
    </xsl:template>
    
    <xsl:template name="status-image">
        <xsl:param name="status"/>
        <xsl:variable name="callback" select="../../callback/@time"/>
        <xsl:if test="$status">
            <xsl:choose>
                <xsl:when test="$status='al' and $callback"><img class="call-icon" src="app-images/no_res_callback.jpg"/></xsl:when>
                <xsl:when test="$status='al' and not($callback)"><img class="call-icon" src="app-images/no_res.jpg"/></xsl:when>
                <xsl:when test="$status='bu' and $callback"><img class="call-icon" src="app-images/busy_callback.jpg"/></xsl:when>
                <xsl:when test="$status='bu' and not($callback)"><img class="call-icon" src="app-images/busy.jpg"/></xsl:when>
                <xsl:when test="$status='co' and $callback"><img class="call-icon" src="app-images/conn_callback.jpg"/></xsl:when>
                <xsl:when test="$status='co' and not($callback)"><img class="call-icon" src="app-images/conn.jpg"/></xsl:when>
                <xsl:when test="$status='er' and $callback"><img class="call-icon" src="app-images/error_callback.jpg"/></xsl:when>
                <xsl:when test="$status='er' and not($callback)"><img class="call-icon" src="app-images/error.jpg"/></xsl:when>
            </xsl:choose>
        </xsl:if>
    </xsl:template>
    
    <xsl:template name="direction-image">
        <xsl:param name="caller"/>
        <xsl:choose>
            <xsl:when test="$caller and $caller='ep1'"><img class="call-icon" src="app-images/dir_out.jpg"/></xsl:when>
            <xsl:when test="$caller and $caller='ep2'"><img class="call-icon" src="app-images/dir_in.jpg"/></xsl:when>
        </xsl:choose>
    </xsl:template>
    
    <xsl:template name="format-ep">
        <xsl:param name="e164"/>
        <xsl:param name="h323"/>
        <xsl:param name="dn"/>
        <xsl:param name="position"/>
        <xsl:if test="$h323 and $h323!=''">
            <xsl:value-of select="$h323"/>
            <xsl:if test="$e164 and $e164!=''"> (<xsl:value-of select="$e164"/>) </xsl:if>
	    <xsl:if test="not($e164) or $e164=''"><xsl:value-of select="' '"/></xsl:if>
            <xsl:if test="$dn and $dn!=''"><xsl:value-of select="$dn"/></xsl:if>
        </xsl:if>
        <xsl:if test="not($h323) or $h323=''">
            <xsl:if test="$e164 and $e164!=''">
                <xsl:value-of select="$e164"/>
                <xsl:if test="$dn and $dn!=''">
                    <xsl:value-of select="' '"/>
                    <xsl:value-of select="$dn"/>
                </xsl:if>
            </xsl:if>
            <xsl:if test="not($e164) or $e164=''">
                <xsl:if test="$dn and $dn!=''">
                    <xsl:value-of select="$dn"/>
                </xsl:if>
                <xsl:if test="(not($dn) or $dn='') and $position=1">(N/A)</xsl:if>
            </xsl:if>
        </xsl:if>
    </xsl:template>
</xsl:stylesheet>
